@@ -6,7 +6,7 @@
  * Date        : 2007-12-08
  * Description : Time line sidebar tab contents.
  *
- * Copyright (C) 2007-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,10 +21,9 @@
  *
  * ============================================================ */
 
-#include "timelineview.h"
 #include "timelineview.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QButtonGroup>
 #include <QFrame>
@@ -35,12 +34,11 @@
 #include <QTimer>
 #include <QToolButton>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kcombobox.h>
 #include <kconfig.h>
-#include <kdebug.h>
 #include <kdialog.h>
 #include <khbox.h>
 #include <kiconloader.h>
@@ -50,8 +48,9 @@
 #include <kmessagebox.h>
 #include <ksqueezedtextlabel.h>
 #include <kstandarddirs.h>
+#include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "album.h"
 #include "albummanager.h"
@@ -68,44 +67,46 @@ class TimeLineViewPriv
 
 public:
 
-    TimeLineViewPriv()
-    {
-        timeUnitCB            = 0;
-        scaleBG               = 0;
-        cursorDateLabel       = 0;
-        cursorCountLabel      = 0;
-        timeLineWidget        = 0;
-        timer                 = 0;
-        scrollBar             = 0;
-        timeLineFolderView    = 0;
-        resetButton           = 0;
-        saveButton            = 0;
-        nameEdit              = 0;
-        searchDateBar         = 0;
-    }
+    TimeLineViewPriv() :
+        configGroupName("TimeLine SideBar"),
+        configHistogramTimeUnitEntry("Histogram TimeUnit"),
+        configHistogramScaleEntry("Histogram Scale"),
+        configCursorPositionEntry("Cursor Position"),
 
-    QScrollBar         *scrollBar;
+        scaleBG(0),
+        cursorCountLabel(0),
+        scrollBar(0),
+        timer(0),
+        resetButton(0),
+        saveButton(0),
+        timeUnitCB(0),
+        nameEdit(0),
+        cursorDateLabel(0),
+        searchDateBar(0),
+        timeLineFolderView(0),
+        timeLineWidget(0)
+    {}
 
-    QTimer             *timer;
 
-    KComboBox          *timeUnitCB;
+    const QString       configGroupName; 
+    const QString       configHistogramTimeUnitEntry;
+    const QString       configHistogramScaleEntry;
+    const QString       configCursorPositionEntry;
 
-    QButtonGroup       *scaleBG;
+    QButtonGroup*       scaleBG;
+    QLabel*             cursorCountLabel;
+    QScrollBar*         scrollBar;
+    QTimer*             timer;
+    QToolButton*        resetButton;
+    QToolButton*        saveButton;
 
-    QLabel             *cursorCountLabel;
+    KComboBox*          timeUnitCB;
+    KLineEdit*          nameEdit;
+    KSqueezedTextLabel* cursorDateLabel;
 
-    QToolButton        *resetButton;
-    QToolButton        *saveButton;
-
-    KLineEdit          *nameEdit;
-
-    KSqueezedTextLabel *cursorDateLabel;
-
-    SearchTextBar      *searchDateBar;
-
-    TimeLineWidget     *timeLineWidget;
-
-    TimeLineFolderView *timeLineFolderView;
+    SearchTextBar*      searchDateBar;
+    TimeLineFolderView* timeLineFolderView;
+    TimeLineWidget*     timeLineWidget;
 };
 
 TimeLineView::TimeLineView(QWidget *parent)
@@ -192,7 +193,7 @@ TimeLineView::TimeLineView(QWidget *parent)
     d->resetButton = new QToolButton(hbox2);
     d->resetButton->setIcon(SmallIcon("document-revert"));
     d->resetButton->setToolTip(i18n("Clear current selection"));
-    d->resetButton->setWhatsThis(i18n("If you press this button, current dates selection from time-line will be clear."));
+    d->resetButton->setWhatsThis(i18n("If you press this button, the current date selection on the time-line will be cleared."));
     d->nameEdit    = new KLineEdit(hbox2);
     d->nameEdit->setClearButtonShown(true);
     d->nameEdit->setWhatsThis(i18n("Enter the name of the current dates search to save in the "
@@ -202,8 +203,8 @@ TimeLineView::TimeLineView(QWidget *parent)
     d->saveButton->setIcon(SmallIcon("document-save"));
     d->saveButton->setEnabled(false);
     d->saveButton->setToolTip(i18n("Save current selection to a new virtual Album"));
-    d->saveButton->setWhatsThis(i18n("If you press this button, current dates selection from time-line will be "
-                                     "saved to a new search virtual Album using name set on the left side."));
+    d->saveButton->setWhatsThis(i18n("If you press this button, the dates selected on the time-line will be "
+                                     "saved to a new search virtual Album using the name set on the left."));
 
     // ---------------------------------------------------------------
 
@@ -319,28 +320,29 @@ void TimeLineView::slotInit()
 void TimeLineView::readConfig()
 {
     KSharedConfig::Ptr config = KGlobal::config();
-    KConfigGroup group        = config->group(QString("TimeLine SideBar"));
+    KConfigGroup group        = config->group(d->configGroupName);
 
-    d->timeUnitCB->setCurrentIndex(group.readEntry("Histogram TimeUnit", (int)TimeLineWidget::Month));
+    d->timeUnitCB->setCurrentIndex(group.readEntry(d->configHistogramTimeUnitEntry, (int)TimeLineWidget::Month));
     slotTimeUnitChanged(d->timeUnitCB->currentIndex());
 
-    int id = group.readEntry("Histogram Scale", (int)TimeLineWidget::LinScale);
+    int id = group.readEntry(d->configHistogramScaleEntry, (int)TimeLineWidget::LinScale);
     if ( d->scaleBG->button( id ) )
        d->scaleBG->button( id )->setChecked(true);
     slotScaleChanged(d->scaleBG->checkedId());
 
     QDateTime now = QDateTime::currentDateTime();
-    d->timeLineWidget->setCursorDateTime(group.readEntry("Cursor Position", now));
+    d->timeLineWidget->setCursorDateTime(group.readEntry(d->configCursorPositionEntry, now));
     d->timeLineWidget->setCurrentIndex(d->timeLineWidget->indexForCursorDateTime());
 }
 
 void TimeLineView::writeConfig()
 {
     KSharedConfig::Ptr config = KGlobal::config();
-    KConfigGroup group        = config->group(QString("TimeLine SideBar"));
-    group.writeEntry("Histogram TimeUnit", d->timeUnitCB->currentIndex());
-    group.writeEntry("Histogram Scale", d->scaleBG->checkedId());
-    group.writeEntry("Cursor Position", d->timeLineWidget->cursorDateTime());
+    KConfigGroup group        = config->group(d->configGroupName);
+
+    group.writeEntry(d->configHistogramTimeUnitEntry, d->timeUnitCB->currentIndex());
+    group.writeEntry(d->configHistogramScaleEntry,    d->scaleBG->checkedId());
+    group.writeEntry(d->configCursorPositionEntry,    d->timeLineWidget->cursorDateTime());
     group.sync();
 }
 
@@ -361,7 +363,7 @@ void TimeLineView::setActive(bool val)
         else
         {
             AlbumList sList = AlbumManager::instance()->allSAlbums();
-            for (AlbumList::iterator it = sList.begin(); it != sList.end(); ++it)
+            for (AlbumList::const_iterator it = sList.constBegin(); it != sList.constEnd(); ++it)
             {
                 SAlbum* salbum = (SAlbum*)(*it);
                 if (salbum->title() == d->timeLineFolderView->currentTimeLineSearchName())
@@ -443,7 +445,7 @@ void TimeLineView::createNewDateSearchAlbum(const QString& name)
     SearchXmlWriter writer;
 
     // for each range, write a group with two fields
-    for (int i=0; i<list.size(); i++)
+    for (int i=0; i<list.size(); ++i)
     {
         writer.writeGroup();
         writer.writeField("creationdate", SearchXml::GreaterThan);
@@ -456,7 +458,7 @@ void TimeLineView::createNewDateSearchAlbum(const QString& name)
     }
     writer.finish();
 
-    kDebug(50003) << "Date search XML:\n" << writer.xml();
+    kDebug() << "Date search XML:\n" << writer.xml();
 
     SAlbum* album = AlbumManager::instance()->createSAlbum(name, DatabaseSearch::TimeLineSearch, writer.xml());
     AlbumManager::instance()->setCurrentAlbum(album);
@@ -495,7 +497,7 @@ void TimeLineView::slotAlbumSelected(SAlbum* salbum)
                         start = reader.valueToDateTime();
                     else if (numberOfFields == 1)
                         end = reader.valueToDateTime();
-                    numberOfFields++;
+                    ++numberOfFields;
                 }
             }
             if (numberOfFields)
@@ -535,9 +537,9 @@ bool TimeLineView::checkName(QString& name)
 
 bool TimeLineView::checkAlbum(const QString& name) const
 {
-    AlbumList list = AlbumManager::instance()->allSAlbums();
+    const AlbumList list = AlbumManager::instance()->allSAlbums();
 
-    for (AlbumList::Iterator it = list.begin() ; it != list.end() ; ++it)
+    for (AlbumList::ConstIterator it = list.constBegin() ; it != list.constEnd() ; ++it)
     {
         SAlbum *album = (SAlbum*)(*it);
         if ( album->title() == name )
